function LmzC = AblockB(LmzA,LmzB,c);
%AblockB  Bivariate polynomial transformation for a block diagonal matrix
%   LmzC = AblockB(LmzA,LmzB,c) returns the bivariate polynomial for 
%   C = diag(A,B) where, 
%   c = size(A)/size(C).
%   
%   Input : LmzA, LmzB, c
%   Output: LmzC 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = LmzA;
%       LmzC = AblockB(LmzA,LmzB,0.5);
%       (should return same value as LmzA)
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Tuesday, January 17, 2006.

syms m z
AoverApB = c;

if (c==1),
    LmzC = LmzA;
elseif (c==0),
    LmzC = LmzB;
else 
   if (LmzA == LmzB),
       LmzC = LmzA;
   else
       LmzA1 = subs(LmzA,m,m/c);
       LmzB1 = subs(LmzB,m,m/(1-c));
 
       LmzC = L1plusL2(LmzA1,LmzB1,m);
   end
end
    
LmzC = irreducLuv(LmzC,m,z);