function LmzB = AgramWish(LmzA,c,s);
%AgramWish  Bivariate polynomial for Grammian transformation
%   LmzB = AgramWish(LmzA,c,s) returns the bivariate polynomial for 
%   B = (As + sqrt(s)*G)*(As + sqrt(s)*G)' where G = randn(n,N) and c = n/N
%
%   Input : LmzA, c, s
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = AgramWish(LmzA,0.5,1);
%       
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Tuesday, January 17, 2006.

syms m z

temp_pol = subs(LmzA,m,m/(1+s*c*m));
temp_pol = subs(temp_pol,z,(1+s*c*m)*(z*(1+s*c*m)+s*(c-1)));

[LmzB, minimal] = irreducLuv(temp_pol,m,z);

if (~minimal)
   LmzB = LmzB/(1+s*c*m);
   LmzB = irreducLuv(LmzB,m,z);
end 
