function LmzC = AplusB(LmzA,LmzB);
%AplusB  Bivariate polynomial for sum of random matrices
%   LmzC = AplusB(LmzA,LmzB) returns the bivariate polynomial for 
%   C = A + Q*B*Q' where Q is Haar unitary
%
%   Input : LmzA, LmzB
%   Output: LmzC
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z
%       LmzA = numden(m-0.5/(1-z)-0.5/(-1-z));
%       LmzB = LmzA;
%       LmzC = AplusB(LmzA,LmzB);
%       (should return arc-sine law)
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Tuesday, January 17, 2006.

syms m z r g


LrgA = Lmz2Lrg(LmzA);

if (LmzA == LmzB),
    LrgB = LrgA;
else
    LrgB = Lmz2Lrg(LmzB);
end
    
LrgC = L1plusL2(LrgA,LrgB,r);

LmzC = Lrg2Lmz(LrgC);


