function LmzC = AtimesB(LmzA,LmzB);
%AtimessB  Bivariate polynomial for product of random matrices
%   LmzC = AtimesB(LmzA,LmzB) returns the bivariate polynomial for 
%   C = A x Q*B*Q' where Q is Haar unitary
%
%   Input : LmzA, LmzB
%   Output: LmzC
%   Assumption: A x B has real eigenvalues
%
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z
%       LmzA = numden(m-0.5/(1-z)-0.5/(0-z));
%       LmzB = LmzA;
%       LmzC = AtimesB(LmzA,LmzB);
%       LmzD = transposeA(LmzC,2)
%      (should return arc-sine law + atom at zero)
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Tuesday, January 17, 2006.

syms m z s y

LsyA = Lmz2Lsy(LmzA);
LsyB = Lmz2Lsy(LmzB);

LsyC = L1timesL2(LsyA,LsyB,s);

LmzC = Lsy2Lmz(LsyC);

