function LmzB = AtimesWish(LmzA,c);
%AtimesWish  Bivariate polynomial for a Wishart matrix with covariance A
%   LmzB = AtimesWish(LmzA,c) returns the bivariate polynomial for 
%   B = A X W(c) where W(c) is Wishart with parameter c
%   Here W(c) = G*G'/N where G = randn(n,N);
%
%   Input : LmzA, c
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = AtimesWish(LmzA,0.5);
%       
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Tuesday, January 17, 2006.

syms m z z1


temp_pol = subs(LmzA,m,m*(1-c-c*z1*m));
temp_pol = subs(temp_pol,z,z1/(1-c-c*z1*m));
temp_pol = subs(temp_pol,z1,z); % Dummy variable 

[LmzB, minimal] = irreducLuv(temp_pol,m,z);    

if (~minimal)
   LmzB = LmzB/(1-c-c*z*m);
   LmzB = irreducLuv(LmzB,m,z);
end 
