function Luv3 = L1plusL2(Luv1,Luv2,u);
%L1plusL2 Computes the bivariate polynomial whose zeros are the sum of the
%         zeros of L1 and L2
% 
%   Luv3 = L1plusL2(Luv1,Luv1,u) computes the bivariate Luv3 whose zeros
%   (with respect to u) are the sum of the zeros of Luv1 and Luv2 (with
%   respect to u)
%   
%   Input : Luv1, Luv2 u (all symbolic)
%   Output: Luv3 
%   
%   Notes: The reference below gives two implementation; one using a matrix
%   theoretic argument; the other in terms of the resultant. The resultant
%   version is much more efficient and is the default computational
%   procedure used.
%               
%   
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.

Cu1 = Luv2Cu(Luv1,u);
Cu2 = Luv2Cu(Luv2,u);

if (Luv1 == Luv2)
    C3 = 2*Cu1;
    Luv3 = det(u*eye(length(C3))-C3);
else
    if (0)
        %%% Matrix theoretic technique 
        C3 = kron(Cu1,eye(length(Cu2))) + kron(eye(length(Cu1)),Cu2); 
        Luv3 = det(u*eye(length(C3))-C3);

    else
        %%% Faster implementation using Maple's resultant command
        syms t
        Luv3 = subs(maple('resultant',Luv1,subs(Luv2,u,t-u),u),t,u);
    end
end


