function Luv3 = L1timesL2(Luv1,Luv2,u);
%L1timesL2 Computes the bivariate polynomial whose zeros are the product
%          of the zeros of L1 and L2
% 
%   Luv3 = L1timesL2(Luv1,Luv1,u) computes the bivariate Luv3 whose zeros
%   (with respect to u) are the product of the zeros of Luv1 and Luv2 (with
%   respect to u)
%   
%   Input : Luv1, Luv2 u (all symbolic)
%   Output: Luv3 
%   
%   Notes: The reference below gives two implementation; one using a matrix
%   theoretic argument; the other in terms of the resultant. The resultant
%   version is much more efficient and is the default computational
%   procedure used.
%               
%   
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.

if (Luv1 == Luv2),
    Cu1 = Luv2Cu(Luv1,u);
    Cu3 = Cu1^2;
    Luv3 = det(u*eye(length(Cu3))-Cu3);
else
    if (0)
        %%% Matrix theoretic technique 

        Cu2 = Luv2Cu(Luv2,u);
        Cu3 = kron(Cu1,Cu2);
        Luv3 = det(u*eye(length(Cu3))-Cu3);
    else
        %%% Using resultants
        syms t
        Du2 = double(maple('degree',Luv2,u));
 
        Luv3 = subs(maple('resultant',Luv1,expand(u^Du2*subs(Luv2,u,t/u)),u),t,u);
    end
end

