function Cmz = TLmz(Lmz);
%TLmz  Returns a (Dm+1) x (Dz+1) matrix of coefficient of the bivariate polynomial Lmz
%   Cmz = TLmz(LmzA) returns a matrix whose (i,j)-th entry is the coefficient associated 
%   with the m^(i-1) z^(j-1) term of the bivariate polynomial Lmz.
%
%   Input : LmzA, 
%   Output: Cmz (matrix)
%     
%
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%
%   Example:
%       syms m z 
%       LmzA = wishartpol(0.5) %% Wishart with parameter 0.5
%       pretty(LmzA)
%       pretty(TLmz(LmzA))
%  
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 31, 2006.

syms m z 

Dm = double(maple('degree',Lmz,m));
Dz = double(maple('degree',Lmz,z));

Cmz = [];

for midx = 0 : Dm,

    Lm = maple('coeff',Lmz,m,midx);
    DZ = [];
    
    for zidx =0 : Dz,
        DZ = [DZ maple('coeff',Lm,z,zidx)];
    end

    Cmz = [Cmz;DZ];
end
