function Lmz = atomLmz(masses,weights);
%atomLmz  Bivariate polynomial for an atomic matrix
%   LmzA = atomLmz(masses,weights) returns the bivariate polynomial for 
%   an atomic matrix A with atoms with locations given by the vector
%   "masses" and associated weights in the vector "weights"
%   
%
%   Input : masses, weights (same sized vectors_
%   Output: Lmz 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = atomLmz([1 2],[0.5 0.5])
%       (is an atomic matrix with half of its eigenvalues equal to 1 and
%       the remaining equal to 2)
%       
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 18, 2006.


syms m z 

Lmz = numden(m-sum(weights./(masses-z)));

    