function LmzB = compressA(LmzA,factor)
%compressA  Bivariate polynomial for a random compression of a matrix
%   LmzB = compressA(LmzA,factor) returns the bivariate polynomial for 
%   Bn = top n-by-n block of the N-by-N matrix Q*A*Q' where Q is Haar
%   unitary
%
%   Input : LmzA, factor
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = numden(m-0.5/(1-z)-0.5/(0-z));
%       LmzB = compressA(LmzA,0.5);
%       (should return arc-sine law)
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Tuesday, January 17, 2006.

syms r g

LmzT = scaleA(LmzA,factor);
LrgT = Lmz2Lrg(LmzT);

LrgB = subs(LrgT,r,r*factor);
LmzB = Lrg2Lmz(LrgB);



