function LmzC = corrWish(LmzA,LmzB,c)
%AplusB  Bivariate polynomial for a spatio-temporally correlated Wishart
%   LmzC = corrWish(LmzA,LmzB,c) returns the bivariate polynomial for 
%   C = Y*Y' where Y = A^{1/2)*G*B^{1/2} where G = randn(n,N) and c = n/N
%
%   Input : LmzA, LmzB, c
%   Output: LmzC 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = LmzA;
%       LmzC = corrWish(LmzA,LmzB,0.5);
%       (see example in paper below)
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Tuesday, January 17, 2006.

syms m z

LmzW = m*(1-c-c*m*z-z)-1;
LmzWt = transposeA(LmzW,c);

LmzT = AtimesB(LmzWt,LmzB);
LmzTt = transposeA(LmzT,1/c);

LmzC = AtimesB(LmzA,LmzTt);

