function LmzA = equiLmz(t,M);
%AplusB  Bivariate polynomial for the equilibrium measure
%   LmzA = equiLmz(t,M) returns the bivariate polynomial for 
%   the equilibrium measure corresponding to the potential \
%   V(x) = t*x^(2*M)
%
%   Input : t, M
%   Output: LmzA 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       LmzA = equiLmz(1,2);
%       (should return semi-circle law)
%
%   Reference: [1] N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%
%   N. Raj Rao, Tuesday, January 17, 2006.

syms m g z a 



a=1;
for l = 1:M
   a = a*(2*l-1)/2/l;
end

a=sym((a*M*t))^(-1/2/M);

h1 = z^(2*M-2);

for j = 1:M-1,

       scaling = 1;
       for l = 1:j,
		 scaling = scaling*(2*l-1)/2/l;
       end
       h1 = h1+z^(2*M-2-2*j)*a^(2*j)*scaling;
end

Lgz = simplify(((g/M/t)-z^(2*M-1))^2-(z^2-a^2)*h1^2);
Lmz = collect(Lgz2Lmz(Lgz),m);

