 function [yc,h]=histw(y,m)
%HISTW Weighted histogram.
%   [YC,H] = HISTW(Y,M) plots a normalized histogram of the data in Y,
%   using M boxes. The output YC contains the bin centers, and H the sum of
%   the weights in each bin.
%
%   Example:
%      y=randn(1e5,1);
%      histw(y,50);

%   Per-Olof Persson <persson@math.mit.edu>, September 2004

w=ones(length(y),1);
dy=(max(y)-min(y))/m;
bin=max(min(floor((y-min(y))/dy)+1,m),1);

yy=min(y)+dy*(0:m);
yc=(yy(1:end-1)+yy(2:end))/2;

h=full(sparse(bin,1,w,m,1));
h = h/((yc(2)-yc(1))*length(w));
bar(yc,h);
