function LmzB = invA(LmzA);
%invA  Bivariate polynomial for B = inv(A)
%   LmzB = invA(LmzA) returns the bivariate polynomial for 
%   B = inv(A)
%
%   Input : LmzA
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = invA(LmzA);
%       
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.


syms m z

LmzB = mobiusA(LmzA,0,1,1,0);
