function LmzB = mobiusA(LmzA,p,q,r,s);
%mobiusA  Bivariate polynomial for B = (p*A+q*I)/(r*A+s*I)
%   LmzB = mobiusA(LmzA,p,q,r,s) returns the bivariate polynomial for 
%   B = (p*A+q*I)/(r*A+s*I)
%
%   Input : LmzA, p, q, r, s
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = invA(LmzA,1,1,1,0);
%       
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.


syms m z
alpha = (q-s*z)/(p-r*z);
beta = 1/(p-r*z);

temp_pol = subs(LmzA,z,-alpha);
temp_pol = subs(temp_pol,m,((m/beta)-r)/(s-r*alpha));

LmzB = irreducLuv(temp_pol,m,z);




