function  LmzB = scaleA(LmzA,alpha);
%scaleA  Bivariate polynomial for B = alpha*A
%   LmzB = scaleA(LmzA,alpha) returns the bivariate polynomial for 
%   B = alpha*A
%
%   Input : LmzA, alpha
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = scaleA(LmzA,2);
%       
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.

LmzB = mobiusA(LmzA,alpha,0,0,1);
