function LmzB = shiftA(LmzA,alpha)
%shiftA  Bivariate polynomial for B = A + alpha*I
%   LmzB = shiftA(LmzA,alpha) returns the bivariate polynomial for 
%   B = A + alpha*I
%
%   Input : LmzA, alpha
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = shiftA(LmzA,-1);
%       
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.

LmzB = mobiusA(LmzA,1,alpha,0,1);
