function LmzB = squareA(LmzA)
%squareA  Bivariate polynomial for B = A^2
%   LmzB = squareA(LmzA) returns the bivariate polynomial for 
%   B = A^2
%   Input : LmzA
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z
%       LmzA = numden(m-0.5/(1-z)-0.5/(2-z));
%       LmzB = squareA(LmzA);
%       MomA = Lmz2MomS(LmzA,10)
%       MomB = Lmz2MomS(LmzB,5)
%       (compare the moments of A and B = A^2)
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.

syms m z

Lmz1 = subs(LmzA,z,sqrt(z));
Lmz1 = subs(Lmz1,m,2*m*sqrt(z));

Lmz2 = subs(LmzA,z,-sqrt(z));
Lmz2 = subs(Lmz2,m,-2*m*sqrt(z));

LmzB = L1plusL2(Lmz1,Lmz2,m);
LmzB = irreducLuv(LmzB,m,z);