function LmzB = transposeA(LmzA,c);
%transposeA  Bivariate polynomial for B = X'*X where A = X*X'
%   LmzB = transposeA(LmzA,c) returns the bivariate polynomial for 
%   B = X'*X where A = X*X' and c = size of A/size of B
%
%   Input : LmzA, c
%   Output: LmzB 
%   
%   Notation: Lmz is the bivariate polynomial satisfied by the Stieltjes
%   transform (see definiton in reference below)
%   
%   Example:
%       syms m z 
%       LmzA = numden(m-0.5/(1-z)-0.5/(0-z));
%       LmzB = transposeA(LmzA,2);
%       
%
%   Reference: N. Raj Rao and Alan Edelman, "The polynomial method for
%   random matrices".
%   
%   N. Raj Rao, Wednesday, January 17, 2006.

syms m z

LmzB = subs(LmzA,m,(1-(1/c))*(1/(0-z))+(m/c));

LmzB = irreducLuv(LmzB,m,z);
